#include <stdlib.h>	/* for atof() */
#include <pango/pangocairo.h>

void draw(cairo_t *cr, double scale, double fontscale);

/*
 * usage: ./a.out scale fontscale output_fname
 * 
 *		for example: ./a.out 2 1 2-1.png
 */

int
main(int argc, char* argv[]) {
	double scale, fontscale;
	char *fname;
	cairo_t *cr;
	cairo_surface_t *surface;
	cairo_status_t status;
	
	if(argc < 4) {
		return 1;
	}
	scale = atof(argv[1]);
	fontscale = atof(argv[2]);
	fname = argv[3];

	surface = cairo_image_surface_create(CAIRO_FORMAT_ARGB32, 200, 100);
	cr = cairo_create(surface);
	cairo_set_source_rgb(cr, 1.0, 1.0, 1.0);
	cairo_paint(cr);

	draw(cr, scale, fontscale);
	
	cairo_destroy(cr);
	status = cairo_surface_write_to_png(surface, fname);
	cairo_surface_destroy(surface);	

	return (status != CAIRO_STATUS_SUCCESS);
}

void
draw(cairo_t *cr, double scale, double fontscale) {
	PangoLayout *layout;
	PangoFontDescription *desc;
	cairo_matrix_t matrix;

	/* set transformation matrix to (1.0/sale)*unit_matrix */
	cairo_matrix_init(&matrix, 1.0/scale, 0., 0., 1.0/scale, 0., 0.);
	cairo_set_matrix(cr,&matrix);

	/* draw a rectangle */
	cairo_set_source_rgb(cr, 0.0, 0.0, 0.0);
	cairo_set_line_width(cr, 2);
	cairo_rectangle(cr, 10, 10, 180, 50);
	cairo_stroke(cr);

	/* draw a text with fontsize = 24*fontscale */
	layout = pango_cairo_create_layout(cr);
	pango_layout_set_text(layout, "Pango Cairo", -1);

	desc = pango_font_description_from_string("Sans Bold 24");
	pango_font_description_set_size(desc, PANGO_SCALE*24*fontscale);
	pango_layout_set_font_description(layout, desc);
	pango_font_description_free(desc);

	cairo_translate(cr, 10, 60);
	pango_cairo_update_layout(cr, layout);
	pango_cairo_show_layout(cr, layout);

	g_object_unref(layout);
}
